Alfredo Library for Python
==========================

    Idiomatic way for Python developers to integrate with Alfredo services.

|build| |coverage| |deploy| |versions|

.. |build| image:: https://travis-ci.org/teamjamon/alfredo-python-sdk.svg?branch=develop
   :target: https://travis-ci.org/rstorcloud/alfredo-python-sdk
.. |coverage| image:: https://coveralls.io/repos/github/teamjamon/alfredo-python-sdk/badge.svg?branch=develop
   :target: https://coveralls.io/github/rstorcloud/alfredo-python-sdk?branch=develop
.. |deploy| image:: https://img.shields.io/pypi/v/alfredo-python.svg
   :target: https://pypi.python.org/pypi/alfredo-python
.. |versions| image:: https://img.shields.io/pypi/pyversions/alfredo-python.svg
   :target: https://pypi.python.org/pypi/alfredo-python
